@@ -5,8 +5,8 @@ import re
 import logging
 
 
-FORMAT = "[%(filename)s:%(lineno)s - %(funcName)20s() ] %(message)s"
-logging.basicConfig(format=FORMAT, level=logging.DEBUG)
+# FORMAT = "[%(filename)s:%(lineno)s - %(funcName)20s() ] %(message)s"
+# logging.basicConfig(format=FORMAT, level=logging.DEBUG)
 
 
 class HyperV:
@@ -102,7 +102,7 @@ class HyperV:
 
 
     # Включение виртуалок
-    def start_vm(self, vms=[]):
+    def vm_start(self, vms=[]):
         ps_script = self.gen_job(vms=vms, job='Start-VM')
         result = self.session.run_ps(ps_script)
         logging.debug(f"result std_out\n{result.std_out.decode('utf-8')}")
@@ -112,7 +112,7 @@ class HyperV:
         return True
 
     # Поставить машины на паузу по маске или передав список машин
-    def VM_suspend(self, vms=[]):
+    def vm_suspend(self, vms=[]):
         ps_script = self.gen_job(vms_list=vms, job='Suspend-VM')
         result = self.session.run_ps(ps_script)
         logging.debug(f"result std_out\n{result.std_out.decode('utf-8')}")
@@ -121,8 +121,10 @@ class HyperV:
             return False
         return True
 
+    
+    
     # Снять машины с паузы по маске или передав список машин
-    def VM_resume(self, vms=[]):
+    def vm_resume(self, vms=[]):
         ps_script = self.gen_job(vms_list=vms, job='Resume-VM')
         result = self.session.run_ps(ps_script)
         logging.debug(f"result std_out: {result.std_out.decode('utf-8')}")
@@ -131,6 +133,23 @@ class HyperV:
             return False
         return True
 
+    # Статус машин
+    def vm_state(self, vms=[]):
+        state_keys = ['state', 'cpu', 'memory', 'uptime' ]
+        ps_script = self.gen_job(vms_list=vms, job='Get-VM')
+        logging.debug(f'ps_script \n{ps_script}')
+        result = self.session.run_ps(ps_script)
+        logging.debug(f"result std_out\n{result.std_out.decode('utf-8')}")
+        logging.debug(f"result status_code \n{result.status_code}")
+        if result.status_code == '1':
+            return False
+           
+        r_result = {}
+        for line in result.std_out.decode('utf-8').splitlines():
+            if line and not 'Name' in line and not '----' in line:
+                # print(line.split()[1])
+                r_result.setdefault(line.split()[0], dict(zip(state_keys, (line.split()[1:5]))))
+        return r_result
     
     # Генерирует PS более/менее стандартные скрипты
     def gen_job(self, job, vms_list=[], **kwargs):
@@ -141,6 +160,7 @@ class HyperV:
             if 'current_snapshot' in kwargs.keys(): params = f"| select Name, ParentSnapshotName"
             if 'dellete_snapshots' in kwargs.keys(): params = f"| Remove-VMSnapshot -Name {kwargs['dellete_snapshots']}"
             if 'apply_snapshots' in kwargs.keys(): params = f"| Restore-VMSnapshot -Name  {kwargs['apply_snapshots']} -Confirm:$false"
+            # if 'state' in kwargs.keys():
 
         all_vms = f"{self.env_prefix}* "
 
